Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
ezdag/dags.py | DAG | 95 | 29 | 0 | 69.5%
ezdag/dags.py | EdgeConnector | 3 | 0 | 0 | 100.0%
ezdag/dags.py | (no class) | 33 | 6 | 0 | 81.8%
ezdag/format.py | (no class) | 41 | 4 | 0 | 90.2%
ezdag/layers.py | Layer | 134 | 16 | 0 | 88.1%
ezdag/layers.py | Node | 13 | 0 | 0 | 100.0%
ezdag/layers.py | HexFormatter | 6 | 0 | 0 | 100.0%
ezdag/layers.py | (no class) | 63 | 0 | 0 | 100.0%
ezdag/options.py | Argument | 20 | 0 | 0 | 100.0%
ezdag/options.py | Option | 24 | 0 | 0 | 100.0%
ezdag/options.py | Literal | 8 | 1 | 0 | 87.5%
ezdag/options.py | (no class) | 44 | 0 | 0 | 100.0%
ezdag/path.py | (no class) | 11 | 0 | 0 | 100.0%
Total |  | 495 | 56 | 0 | 88.7%

No items found using the specified filter.